[jester] more renames and bump version



commit 6e977b6da95ab4ad9805e3e267fea8bb04c1bde3
Author: John (J5) Palmieri <johnp redhat com>
Date:   Tue Mar 23 17:00:28 2010 -0400

    more renames and bump version

 configure.ac           |    2 +-
 js/j5tester.js         |    4 ++--
 js/j5tester_globals.js |    8 ++++----
 3 files changed, 7 insertions(+), 7 deletions(-)
---
diff --git a/configure.ac b/configure.ac
index 86dc61d..aa11d8a 100644
--- a/configure.ac
+++ b/configure.ac
@@ -1,4 +1,4 @@
-AC_INIT(j5tester, 0.1)
+AC_INIT(j5tester, 0.2)
 
 AC_CONFIG_AUX_DIR(config)
 
diff --git a/js/j5tester.js b/js/j5tester.js
index e9de43b..d231f60 100644
--- a/js/j5tester.js
+++ b/js/j5tester.js
@@ -1,4 +1,4 @@
-/* jester.js - main jester module with unit test objects
+/* j5tester.js - main j5tester module with unit test objects
  *
  * This file is licensed under the MIT License
  *
@@ -215,4 +215,4 @@ var Test = function(test_map, indent) {
     };
     
     this.init();
-}
\ No newline at end of file
+}
diff --git a/js/j5tester_globals.js b/js/j5tester_globals.js
index 46fd2d3..0e038f9 100644
--- a/js/j5tester_globals.js
+++ b/js/j5tester_globals.js
@@ -1,4 +1,4 @@
 /* jester_globals.js - defines the global variables for the jester module
  *
  * This file is licensed under the MIT License
  *
@@ -24,7 +24,7 @@
  */
 
 let GLOBAL = this;
-let jester = {
-    version: '0.1',
-    magic: 'GNOME JESTER JAVASCRIPT TESTER'
+let j5tester = {
+    version: '0.2',
+    magic: 'GNOME J5TESTER JAVASCRIPT TESTER'
 };
@@ -1,4 +1,4 @@
-/* jester_globals.js - defines the global variables for the jester module
+/* j5tester_globals.js - defines the global variables for the j5tester module
  *
  * This file is licensed under the MIT License



[Date Prev][Date Next]   [Thread Prev][Thread Next]   [Thread Index] [Date Index] [Author Index]